==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1LoadBalancerIngressFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1LoadBalancerIngressFluentImpl<A extends V1LoadBalancerIngressFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1LoadBalancerIngressFluent<A>{

    private String hostname;
    private String ip;

    public V1LoadBalancerIngressFluentImpl(){
    }
    public V1LoadBalancerIngressFluentImpl(V1LoadBalancerIngress instance){
            this.withHostname(instance.getHostname());

            this.withIp(instance.getIp());

    }

    public String getHostname(){
            return this.hostname;
    }

    public A withHostname(String hostname){
            this.hostname=hostname; return (A) this;
    }

    public Boolean hasHostname(){
            return this.hostname != null;
    }

    public String getIp(){
            return this.ip;
    }

    public A withIp(String ip){
            this.ip=ip; return (A) this;
    }

    public Boolean hasIp(){
            return this.ip != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1LoadBalancerIngressFluentImpl that = (V1LoadBalancerIngressFluentImpl) o;
            if (hostname != null ? !hostname.equals(that.hostname) :that.hostname != null) return false;
            if (ip != null ? !ip.equals(that.ip) :that.ip != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1LoadBalancerIngressFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1LoadBalancerIngressFluentImpl<A extends V1LoadBalancerIngressFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1LoadBalancerIngressFluent<A>{

    private String hostname;
    private String ip;

    public V1LoadBalancerIngressFluentImpl(){
    }
    public V1LoadBalancerIngressFluentImpl(V1LoadBalancerIngress instance){
            this.withHostname(instance.getHostname());

            this.withIp(instance.getIp());

    }

    public String getHostname(){
            return this.hostname;
    }

    public A withHostname(String hostname){
            this.hostname=hostname; return (A) this;
    }

    public Boolean hasHostname(){
            return this.hostname != null;
    }

    public A withNewHostname(String arg1){
            return (A)withHostname(new String(arg1));
    }

    public A withNewHostname(StringBuilder arg1){
            return (A)withHostname(new String(arg1));
    }

    public A withNewHostname(StringBuffer arg1){
            return (A)withHostname(new String(arg1));
    }

    public String getIp(){
            return this.ip;
    }

    public A withIp(String ip){
            this.ip=ip; return (A) this;
    }

    public Boolean hasIp(){
            return this.ip != null;
    }

    public A withNewIp(String arg1){
            return (A)withIp(new String(arg1));
    }

    public A withNewIp(StringBuilder arg1){
            return (A)withIp(new String(arg1));
    }

    public A withNewIp(StringBuffer arg1){
            return (A)withIp(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1LoadBalancerIngressFluentImpl that = (V1LoadBalancerIngressFluentImpl) o;
            if (hostname != null ? !hostname.equals(that.hostname) :that.hostname != null) return false;
            if (ip != null ? !ip.equals(that.ip) :that.ip != null) return false;
            return true;
    }




}
